package de.masterfacture.ProductionPlanning.Interfaces;

import java.util.*;

/**
 * The interface for nodes in a graph.
 * @author macke
 *
 */
public interface INode
{
	/**
	 * Returns the ID of the current node.
	 * @return The ID of the current node.
	 */
	String getID();
	
	/**
	 * Returns a list of the current node's successor nodes.
	 * @return A list of the current node's successor nodes.
	 */
	ArrayList<INode> getSuccessors();
	
	/**
	 * Returns the current node's predecessor.
	 * @return The current node's predecessor.
	 */
	INode getPredecessor();
	
	/**
	 * Sets the current node's predecessor.
	 * @param predecessor The current node's new predecessor.
	 */
	void setPredecessor(INode predecessor);
	
	/**
	 * Returns the distance from the current node to the given
	 * successor.
	 * @param successor The successor to get the distance for.
	 * @return The distance between the current node and the given successor.
	 */
	double getDistanceToSuccessor(INode successor);
}
