package de.masterfacture.ProductionPlanning.RouteCalculation;

import java.util.Dictionary;
import java.util.Hashtable;

import de.masterfacture.ProductionPlanning.Interfaces.*;

/**
 * The graph of the production plant.
 * @author macke
 *
 */
public class ProductionPlant implements IGraph
{
	/**
	 * A dictionary containing all parts of the production plant.
	 */
	private Dictionary<String, INode> parts;
	
	
	public INode getNode(String id)
	{
		// TODO: throw exception if part with given ID does not exist
		return this.parts.get(id);
	}

	/**
	 * Constructor.
	 */
	public ProductionPlant()
	{
		// TODO: create graph based on XML file from editor
		this.parts = new Hashtable<String, INode>();

		// create parts
		ProductionPlantPart warehouse = new HighBayWarehouse("Warehouse", ProductionPlantPartType.HighBayWarehouse);

		Conveyor c01 = new Conveyor("C01", ProductionPlantPartType.Conveyor);
		Conveyor c02 = new Conveyor("C02", ProductionPlantPartType.Conveyor);
		Conveyor c03 = new Conveyor("C03", ProductionPlantPartType.Conveyor);
		c03.setLength(3);
		Conveyor c04 = new Conveyor("C04", ProductionPlantPartType.Conveyor);
		c04.setLength(2);
		Conveyor c05 = new Conveyor("C05", ProductionPlantPartType.Conveyor);
		Conveyor c06 = new Conveyor("C06", ProductionPlantPartType.Conveyor);
		Conveyor c07 = new Conveyor("C07", ProductionPlantPartType.Conveyor);
		c07.setLength(2);
		Conveyor c08 = new Conveyor("C08", ProductionPlantPartType.Conveyor);
		Conveyor c09 = new Conveyor("C09", ProductionPlantPartType.Conveyor);
		c09.setLength(2);
		Conveyor c10 = new Conveyor("C10", ProductionPlantPartType.Conveyor);
		c10.setLength(3);
		Conveyor c11 = new Conveyor("C11", ProductionPlantPartType.Conveyor);
		Conveyor c12 = new Conveyor("C12", ProductionPlantPartType.Conveyor);
		Conveyor c13 = new Conveyor("C13", ProductionPlantPartType.Conveyor);
		c13.setLength(5);
		Conveyor c14 = new Conveyor("C14", ProductionPlantPartType.Conveyor);
		Conveyor c15 = new Conveyor("C15", ProductionPlantPartType.Conveyor);
		c15.setLength(5);
		Conveyor c16 = new Conveyor("C16", ProductionPlantPartType.Conveyor);
		c16.setLength(5);
		
		ProductionPlantPart psa1 = new ProductionStation("StationA1", ProductionPlantPartType.ProductionStation);
		ProductionPlantPart psa2 = new ProductionStation("StationA2", ProductionPlantPartType.ProductionStation);
		ProductionPlantPart psb1 = new ProductionStation("StationB", ProductionPlantPartType.ProductionStation);

		ProductionPlantPart rp01 = new ProductionStation("RP01", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp02 = new ProductionStation("RP02", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp03 = new ProductionStation("RP03", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp04 = new ProductionStation("RP04", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp05 = new ProductionStation("RP05", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp06 = new ProductionStation("RP06", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp07 = new ProductionStation("RP07", ProductionPlantPartType.RotaryPlate);
		ProductionPlantPart rp08 = new ProductionStation("RP08", ProductionPlantPartType.RotaryPlate);
		
		ProductionPlantPart ramp = new ProductionStation("Ramp", ProductionPlantPartType.Ramp);

		
		// link parts
		warehouse.addSuccessor(c01);
		warehouse.addSuccessor(c11);

		ramp.addSuccessor(c08);
		
		psa1.addSuccessor(c15);
		psa1.addSuccessor(c14);
		
		psa2.addSuccessor(c05);
		psa2.addSuccessor(c06);

		psb1.addSuccessor(c14);
		psb1.addSuccessor(c13);
		
		c01.addSuccessor(warehouse);
		c01.addSuccessor(rp01);

		rp01.addSuccessor(c01);
		rp01.addSuccessor(c02);
		rp01.addSuccessor(c16);

		c02.addSuccessor(rp01);
		c02.addSuccessor(rp02);

		rp02.addSuccessor(c02);
		rp02.addSuccessor(c03);

		c03.addSuccessor(rp02);
		c03.addSuccessor(rp03);

		rp03.addSuccessor(c03);
		rp03.addSuccessor(c15);
		rp03.addSuccessor(c04);

		c04.addSuccessor(rp03);
		c04.addSuccessor(rp04);

		rp04.addSuccessor(c04);
		rp04.addSuccessor(c05);

		c05.addSuccessor(rp04);
		c05.addSuccessor(psa2);

		c06.addSuccessor(psa2);
		c06.addSuccessor(c07);

		c07.addSuccessor(c06);
		c07.addSuccessor(rp05);
		
		rp05.addSuccessor(c07);
		rp05.addSuccessor(c08);
		rp05.addSuccessor(c09);

		c08.addSuccessor(ramp);
		c08.addSuccessor(rp05);

		c09.addSuccessor(rp06);
		c09.addSuccessor(rp05);

		rp06.addSuccessor(c09);
		rp06.addSuccessor(c13);
		rp06.addSuccessor(c10);

		c10.addSuccessor(rp06);
		c10.addSuccessor(rp07);

		rp07.addSuccessor(c10);
		rp07.addSuccessor(c11);

		c11.addSuccessor(rp07);
		c11.addSuccessor(rp08);

		rp08.addSuccessor(c11);
		rp08.addSuccessor(c12);
		rp08.addSuccessor(c16);

		c12.addSuccessor(warehouse);
		c12.addSuccessor(rp08);

		c16.addSuccessor(rp08);
		c16.addSuccessor(rp01);

		c15.addSuccessor(psa1);
		c15.addSuccessor(rp03);

		c14.addSuccessor(psb1);
		c14.addSuccessor(psa1);

		c13.addSuccessor(rp06);
		c13.addSuccessor(psb1);
		
		
		// add parts to graph
		this.parts.put(warehouse.getID(), warehouse);
		this.parts.put(psa1.getID(), psa1);
		this.parts.put(psa2.getID(), psa2);
		this.parts.put(psb1.getID(), psb1);
		this.parts.put(ramp.getID(), ramp);
		
		this.parts.put(c01.getID(), c01);
		this.parts.put(c02.getID(), c02);
		this.parts.put(c03.getID(), c03);
		this.parts.put(c04.getID(), c04);
		this.parts.put(c05.getID(), c05);
		this.parts.put(c06.getID(), c06);
		this.parts.put(c07.getID(), c07);
		this.parts.put(c08.getID(), c08);
		this.parts.put(c09.getID(), c09);
		this.parts.put(c10.getID(), c10);
		this.parts.put(c11.getID(), c11);
		this.parts.put(c12.getID(), c12);
		this.parts.put(c13.getID(), c13);
		this.parts.put(c14.getID(), c14);
		this.parts.put(c15.getID(), c15);
		this.parts.put(c16.getID(), c16);

		this.parts.put(rp01.getID(), rp01);
		this.parts.put(rp02.getID(), rp02);
		this.parts.put(rp03.getID(), rp03);
		this.parts.put(rp04.getID(), rp04);
		this.parts.put(rp05.getID(), rp05);
		this.parts.put(rp06.getID(), rp06);
		this.parts.put(rp07.getID(), rp07);
		this.parts.put(rp08.getID(), rp08);	
	}
}
