package de.masterfacture.ProductionPlanning.RouteCalculation;

import de.masterfacture.ProductionPlanning.Interfaces.*;

import java.util.*;

public abstract class ProductionPlantPart implements INode
{
	/**
	 * The current part's ID.
	 */
	private String id;

	/**
	 * The current part's type.
	 */
	private ProductionPlantPartType type;
	
	/**
	 * A list of the current part's successors.
	 */
	private ArrayList<INode> successors;
	
	/**
	 * The current part's predecessor.
	 */
	private INode predecessor;

	/**
	 * Constructor.
	 * @param id The new part's ID.
	 * @param type The new part's type.
	 */
	public ProductionPlantPart(String id, ProductionPlantPartType type)
	{
		this.id = id;
		this.type = type;
	}

	public INode getPredecessor()
	{
		return this.predecessor;
	}

	public void setPredecessor(INode predecessor)
	{
		this.predecessor = predecessor;
	}

	public String getID()
	{
		return this.id;
	}

	public ProductionPlantPartType getType()
	{
		return this.type;
	}

	public ArrayList<INode> getSuccessors()
	{
		return this.successors;
	}
	
	/**
	 * Adds a part to the list of the current part's successors.
	 * @param successor The new successor part.
	 */
	public void addSuccessor(INode successor)
	{
		if (this.successors == null)
			this.successors = new ArrayList<INode>();
		this.successors.add(successor);
	}
	
	public String toString()
	{
		return this.type + " " + this.id;
	}
	
	public double getDistanceToSuccessor(INode theSuccessor)
	{
		double distance = 0;
		if (this.getClass() == Conveyor.class)
			distance = ((Conveyor)this).getLength();
		return distance;
	}
}
