package de.masterfacture.ProductionPlanning.RouteCalculation;

import de.masterfacture.ProductionPlanning.Interfaces.INode;

/**
 * Represents a connection between two parts of the production plant.
 * 
 * This class contains the needed attributes to describe a connection
 * between two parts of the production plant (e.g. distance). 
 * @author macke
 *
 */
public class ProductionPlantPartConnection
{
	/**
	 * The connection's source part.
	 */
	private INode source;
	
	/**
	 * The connection's target part.
	 */
	private INode target;
	
	/**
	 * The distance between the connection's source and target.
	 */
	private double distance;
	
	/**
	 * The time a pallet needs to get from the source part to the target part.
	 */
	private double timeInterval;
	
	/**
	 * Constructor.
	 * @param source The source part.
	 * @param target The target part.
	 */
	public ProductionPlantPartConnection(INode source, INode target)
	{
		this.source = source;
		this.target = target;
		this.distance = 1;
		this.timeInterval = 1;
	}

	/**
	 * Returns the distance between the source part and the target part. 
	 * @return The distance between the source part and the target part.
	 */
	public double getDistance()
	{
		return distance;
	}

	/**
	 * Sets the distance between the source part and the target part.
	 * @param distance The distance between the source part and the target part.
	 */
	public void setDistance(double distance)
	{
		this.distance = distance;
	}

	/**
	 * Returns the time interval a pallet needs to get from the source part to the target part.
	 * @return The time interval a pallet needs to get from the source part to the target part.
	 */
	public double getTimeInterval()
	{
		return timeInterval;
	}

	/**
	 * Sets the time interval a pallet needs to get from the source part to the target part.
	 * @param timeInterval The time interval a pallet needs to get from the source part to the target part.
	 */
	public void setTimeInterval(double timeInterval)
	{
		this.timeInterval = timeInterval;
	}

	/**
	 * Returns the connection's source part.
	 * @return The connection's source part.
	 */
	public INode getSource()
	{
		return source;
	}

	/**
	 * Returns the connection's target part.
	 * @return The connection's target part.
	 */
	public INode getTarget()
	{
		return target;
	}	
}
